@@ -3,7 +3,7 @@
  * GData Client
  * Copyright (C) Thibault Saunier 2009 <saunierthibault@gmail.com>
  * Copyright (C) Philip Withnall 2010, 2014 <philip@tecnocode.co.uk>
- * Copyright (C) Red Hat, Inc. 2015
+ * Copyright (C) Red Hat, Inc. 2015, 2016
  *
  * GData Client is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -247,7 +247,7 @@
  * </example>
  *
  * Since: 0.4.0
- **/
+ */
 
 #include <config.h>
 #include <glib.h>
@@ -270,17 +270,6 @@ gdata_documents_service_error_quark (void)
 
 static void append_query_headers (GDataService *self, GDataAuthorizationDomain *domain, SoupMessage *message);
 static GList *get_authorization_domains (void);
-static GDataFeed *
-parse_feed (GDataService *self,
-            GDataAuthorizationDomain *domain,
-            GDataQuery *query,
-            GType entry_type,
-            SoupMessage *message,
-            GCancellable *cancellable,
-            GDataQueryProgressCallback progress_callback,
-            gpointer progress_user_data,
-            GError **error);
-
 static gchar *_get_upload_uri_for_query_and_folder (GDataDocumentsUploadQuery *query,
                                                     GDataDocumentsFolder *folder) G_GNUC_WARN_UNUSED_RESULT G_GNUC_MALLOC;
 
@@ -296,7 +285,6 @@ gdata_documents_service_class_init (GDataDocumentsServiceClass *klass)
 
 	service_class->append_query_headers = append_query_headers;
 	service_class->get_authorization_domains = get_authorization_domains;
-	service_class->parse_feed = parse_feed;
 
 	service_class->api_version = "3";
 }
@@ -361,53 +349,6 @@ get_authorization_domains (void)
 	return authorization_domains;
 }
 
-static GDataFeed *
-parse_feed (GDataService *self,
-            GDataAuthorizationDomain *domain,
-            GDataQuery *query,
-            GType entry_type,
-            SoupMessage *message,
-            GCancellable *cancellable,
-            GDataQueryProgressCallback progress_callback,
-            gpointer progress_user_data,
-            GError **error)
-{
-	GDataServiceClass *klass;  /* unowned */
-	GDataFeed *feed = NULL;  /* owned */
-
-	klass = GDATA_SERVICE_CLASS (gdata_documents_service_parent_class);
-
-	/* Parse the feed. */
-	feed = klass->parse_feed (self, domain, query, entry_type, message,
-	                          cancellable, progress_callback,
-	                          progress_user_data, error);
-
-	/* Update the query with the next and previous URIs from the feed. If
-	 * they are not present, we are on the first or final page of the
-	 * feed. (This behaviour is specific to Google Docs.) */
-	if (query != NULL && feed != NULL) {
-		GDataLink *_link;
-
-		_link = gdata_feed_look_up_link (feed, "http://www.iana.org/assignments/relation/next");
-
-		if (_link != NULL) {
-			_gdata_query_set_next_uri (query, gdata_link_get_uri (_link));
-		} else {
-			_gdata_query_set_next_uri_end (query);
-		}
-
-		_link = gdata_feed_look_up_link (feed, "http://www.iana.org/assignments/relation/previous");
-
-		if (_link != NULL) {
-			_gdata_query_set_previous_uri (query, gdata_link_get_uri (_link));
-		} else {
-			_gdata_query_set_previous_uri_end (query);
-		}
-	}
-
-	return feed;
-}
-
 /**
  * gdata_documents_service_new:
  * @authorizer: (allow-none): a #GDataAuthorizer to authorize the service's requests, or %NULL
@@ -492,7 +433,7 @@ _query_documents_build_request_uri (GDataDocumentsQuery *query)
  * Return value: (transfer full): a #GDataDocumentsFeed of query results; unref with g_object_unref()
  *
  * Since: 0.4.0
- **/
+ */
 GDataDocumentsFeed *
 gdata_documents_service_query_documents (GDataDocumentsService *self, GDataDocumentsQuery *query, GCancellable *cancellable,
                                          GDataQueryProgressCallback progress_callback, gpointer progress_user_data,
@@ -541,7 +482,7 @@ gdata_documents_service_query_documents (GDataDocumentsService *self, GDataDocum
  * and gdata_service_query_async(), which is the base asynchronous query function.
  *
  * Since: 0.9.1
- **/
+ */
 void
 gdata_documents_service_query_documents_async (GDataDocumentsService *self, GDataDocumentsQuery *query, GCancellable *cancellable,
                                                GDataQueryProgressCallback progress_callback, gpointer progress_user_data,
@@ -671,7 +612,7 @@ _upload_checks (GDataDocumentsService *self, GDataDocumentsDocument *document, G
  * Return value: (transfer full): a #GDataUploadStream to write the document data to, or %NULL; unref with g_object_unref()
  *
  * Since: 0.8.0
- **/
+ */
 GDataUploadStream *
 gdata_documents_service_upload_document (GDataDocumentsService *self, GDataDocumentsDocument *document, const gchar *slug, const gchar *content_type,
                                          GDataDocumentsFolder *folder, GCancellable *cancellable, GError **error)
@@ -814,7 +755,7 @@ _update_checks (GDataDocumentsService *self, GError **error)
  * Return value: (transfer full): a #GDataUploadStream to write the document data to; unref with g_object_unref()
  *
  * Since: 0.8.0
- **/
+ */
 GDataUploadStream *
 gdata_documents_service_update_document (GDataDocumentsService *self, GDataDocumentsDocument *document, const gchar *slug, const gchar *content_type,
                                          GCancellable *cancellable, GError **error)
@@ -943,7 +884,7 @@ gdata_documents_service_finish_upload (GDataDocumentsService *self, GDataUploadS
 
 	if (g_type_is_a (new_document_type, GDATA_TYPE_DOCUMENTS_DOCUMENT) == FALSE) {
 		g_set_error (error, GDATA_DOCUMENTS_SERVICE_ERROR, GDATA_DOCUMENTS_SERVICE_ERROR_INVALID_CONTENT_TYPE,
-		             _("The content type of the supplied document ('%s') could not be recognized."),
+		             _("The content type of the supplied document (‘%s’) could not be recognized."),
 		             content_type);
 		return NULL;
 	}
@@ -1131,7 +1072,7 @@ gdata_documents_service_copy_document_finish (GDataDocumentsService *self, GAsyn
  * Return value: (transfer full): an updated #GDataDocumentsEntry, or %NULL; unref with g_object_unref()
  *
  * Since: 0.8.0
- **/
+ */
 GDataDocumentsEntry *
 gdata_documents_service_add_entry_to_folder (GDataDocumentsService *self, GDataDocumentsEntry *entry, GDataDocumentsFolder *folder,
                                              GCancellable *cancellable, GError **error)
@@ -1140,6 +1081,7 @@ gdata_documents_service_add_entry_to_folder (GDataDocumentsService *self, GDataD
 	GDataDocumentsEntry *local_entry;
 	GDataOperationType operation_type;
 	GType entry_type;
+	const gchar *content_type;
 	const gchar *etag;
 	const gchar *title;
 	const gchar *uri_prefix = "https://www.googleapis.com/drive/v2/files";
@@ -1173,9 +1115,11 @@ gdata_documents_service_add_entry_to_folder (GDataDocumentsService *self, GDataD
 	}
 
 	entry_type = G_OBJECT_TYPE (entry);
+	content_type = gdata_documents_utils_get_content_type (entry);
 	etag = gdata_entry_get_etag (GDATA_ENTRY (entry));
 	title = gdata_entry_get_title (GDATA_ENTRY (entry));
 	local_entry = g_object_new (entry_type, "etag", etag, "title", title, NULL);
+	gdata_documents_utils_add_content_type (local_entry, content_type);
 	add_folder_link_to_entry (local_entry, folder);
 
 	message = _gdata_service_build_message (GDATA_SERVICE (self), get_documents_authorization_domain (), SOUP_METHOD_POST, uri, NULL, FALSE);
@@ -1264,7 +1208,7 @@ add_entry_to_folder_thread (GSimpleAsyncResult *result, GDataDocumentsService *s
  * of the operation.
  *
  * Since: 0.8.0
- **/
+ */
 void
 gdata_documents_service_add_entry_to_folder_async (GDataDocumentsService *self, GDataDocumentsEntry *entry, GDataDocumentsFolder *folder,
                                                    GCancellable *cancellable, GAsyncReadyCallback callback, gpointer user_data)
@@ -1298,7 +1242,7 @@ gdata_documents_service_add_entry_to_folder_async (GDataDocumentsService *self,
  * Return value: (transfer full): an updated #GDataDocumentsEntry, or %NULL; unref with g_object_unref()
  *
  * Since: 0.8.0
- **/
+ */
 GDataDocumentsEntry *
 gdata_documents_service_add_entry_to_folder_finish (GDataDocumentsService *self, GAsyncResult *async_result, GError **error)
 {
@@ -1337,7 +1281,7 @@ gdata_documents_service_add_entry_to_folder_finish (GDataDocumentsService *self,
  * Return value: (transfer full): an updated #GDataDocumentsEntry, or %NULL; unref with g_object_unref()
  *
  * Since: 0.8.0
- **/
+ */
 GDataDocumentsEntry *
 gdata_documents_service_remove_entry_from_folder (GDataDocumentsService *self, GDataDocumentsEntry *entry, GDataDocumentsFolder *folder,
                                                   GCancellable *cancellable, GError **error)
@@ -1449,7 +1393,7 @@ remove_entry_from_folder_thread (GSimpleAsyncResult *result, GDataDocumentsServi
  * results of the operation.
  *
  * Since: 0.8.0
- **/
+ */
 void
 gdata_documents_service_remove_entry_from_folder_async (GDataDocumentsService *self, GDataDocumentsEntry *entry, GDataDocumentsFolder *folder,
                                                         GCancellable *cancellable, GAsyncReadyCallback callback, gpointer user_data)
@@ -1484,7 +1428,7 @@ gdata_documents_service_remove_entry_from_folder_async (GDataDocumentsService *s
  * Return value: (transfer full): an updated #GDataDocumentsEntry, or %NULL; unref with g_object_unref()
  *
  * Since: 0.8.0
- **/
+ */
 GDataDocumentsEntry *
 gdata_documents_service_remove_entry_from_folder_finish (GDataDocumentsService *self, GAsyncResult *async_result, GError **error)
 {
@@ -1533,7 +1477,7 @@ _get_upload_uri_for_query_and_folder (GDataDocumentsUploadQuery *query, GDataDoc
  * Return value: the URI permitting the upload of documents to @folder, or %NULL; free with g_free()
  *
  * Since: 0.5.0
- **/
+ */
 gchar *
 gdata_documents_service_get_upload_uri (GDataDocumentsFolder *folder)
 {
